@@ -2,18 +2,19 @@ package LCFG::Build::Tool::DevPack;    # -*-perl-*-
 use strict;
 use warnings;
 
-# $Id: DevPack.pm.in 29224 2015-11-12 10:11:34Z squinney@INF.ED.AC.UK $
+# $Id: DevPack.pm.in 35404 2019-01-17 15:06:31Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Tool/DevPack.pm.in,v $
-# $Revision: 29224 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_6/lib/LCFG/Build/Tool/DevPack.pm.in $
-# $Date: 2015-11-12 10:11:34 +0000 (Thu, 12 Nov 2015) $
+# $Revision: 35404 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_9_18/lib/LCFG/Build/Tool/DevPack.pm.in $
+# $Date: 2019-01-17 15:06:31 +0000 (Thu, 17 Jan 2019) $
 
-our $VERSION = '0.6.6';
+our $VERSION = '0.9.18';
 
 use File::Path ();
 use File::Spec ();
 use File::Temp ();
 use LCFG::Build::Utils;
+use LCFG::Build::Utils::Debian;
 use UNIVERSAL::require;
 
 use Moose;
@@ -75,12 +76,9 @@ sub execute {
         $spec->save_metafile;
     }
 
-    # From this point on only use the cloned object.
+    # From this point on only use the cloned (new_spec) object.
 
-    my $module = $new_spec->fullname;
-
-    my $dirname = join q{-}, $module, $version;
-    my $outdir = File::Spec->catdir( $self->resultsdir, $dirname );
+    my $outdir = $self->output_dir;
 
     if ( -d $outdir ) {
         File::Path::rmtree $outdir;
@@ -105,6 +103,10 @@ sub execute {
     # dry-run but it is hard to do much more when the export has not
     # done anything.
 
+    my $plugin_opts = {
+        devel_build => 1,
+    };
+
     if ( !$self->dryrun ) {
 
         if ( $self->translate ) {
@@ -118,21 +120,10 @@ sub execute {
             $self->log('Successfully generated cmake files.');
         }
 
-        for my $util ( LCFG::Build::Utils->plugins() ) {
-            $util->require or $self->fail($@);
-            my $type = ( split /::/, $util )[-1];
-
-            if ( $util->can('generate_metadata') ) {
-                eval {
-                    $util->generate_metadata( $new_spec, $srcdir, $outdir )
-                };
-                if ($@) {
-                    $self->fail("Failed to generate package metadata files for $type: $@");
-                }
-
-                $self->log("Successfully generated metadata files for $type");
-            }
-        }
+        LCFG::Build::Utils->run_plugins_method( 'generate_metadata',
+                                                $new_spec, $srcdir,
+                                                $outdir,
+                                                $plugin_opts );
 
         # We MUST pack *AFTER* generating the metadata in case the
         # metadata files need to be inserted into the generated tar
@@ -144,6 +135,14 @@ sub execute {
         $self->log('Successfully generated source tar file.');
         $self->log("Tar file is: $tarfile");
 
+        # Some plugins need to generate metadata AFTER the source has
+        # been packed, for example, Debian.
+
+        LCFG::Build::Utils->run_plugins_method( 'generate_metadata_post',
+                                                $new_spec, $srcdir,
+                                                $outdir,
+                                                $plugin_opts );
+
     }
 
     return;
@@ -159,7 +158,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::Tool::DevPack version 0.6.6
+    This documentation refers to LCFG::Build::Tool::DevPack version 0.9.18
 
 =head1 SYNOPSIS
 
