@@ -2,13 +2,13 @@ package LCFG::Build::Tool::MicroVersion;    # -*-perl-*-
 use strict;
 use warnings;
 
-# $Id: MicroVersion.pm.in 29224 2015-11-12 10:11:34Z squinney@INF.ED.AC.UK $
+# $Id: MicroVersion.pm.in 35202 2018-12-12 15:10:41Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Tool/MicroVersion.pm.in,v $
-# $Revision: 29224 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_6/lib/LCFG/Build/Tool/MicroVersion.pm.in $
-# $Date: 2015-11-12 10:11:34 +0000 (Thu, 12 Nov 2015) $
+# $Revision: 35202 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_9_18/lib/LCFG/Build/Tool/MicroVersion.pm.in $
+# $Date: 2018-12-12 15:10:41 +0000 (Wed, 12 Dec 2018) $
 
-our $VERSION = '0.6.6';
+our $VERSION = '0.9.18';
 
 use Moose;
 
@@ -42,6 +42,14 @@ has 'genchangelog' => (
     documentation => 'Generate the change log from the VCS log',
 );
 
+has 'store_version' => (
+    is            => 'rw',
+    isa           => 'Bool',
+    lazy          => 1,
+    default       => sub { $_[0]->spec->get_vcsinfo('store_version') },
+    documentation => 'Store the version string into a simple text file',
+);
+    
 override '_load_vcs_module' => sub {
     my ($self) = @_;
 
@@ -107,6 +115,16 @@ sub release {
         $spec->save_metafile();
     }
 
+    if ( $self->store_version ) {
+        $vcs->store_version($spec->version);
+    }
+
+    my $debdir = File::Spec->catdir( $self->dir, 'debian' );
+    if ( -d $debdir && !$self->dryrun ) {
+        $self->log('Updating debian/changelog');
+        $vcs->update_changelog( $spec->version, { style => 'debian' } );
+    }
+
     $vcs->tagversion( $spec->version );
 
     return;
@@ -134,7 +152,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::Tool::MicroVersion version 0.6.6
+    This documentation refers to LCFG::Build::Tool::MicroVersion version 0.9.18
 
 =head1 SYNOPSIS
 
@@ -213,6 +231,13 @@ the software project should be generated from the commit logs of the
 version-control system. By default the value specified in the LCFG
 metadata file will be used.
 
+=item store_version
+
+This is a boolean value which controls whether the version string
+(e.g. C<1.2.3>) should be stored into a F<lcfg-build-id.txt> file when
+a new project version is tagged. By default the value specified in the
+LCFG metadata file will be used.
+
 =back
 
 The following methods are not modifiable by the command-line, they are
